==> mysql-shell-8.0.17-src.tar.gz: mysql-shell-8.0.17-src/unittest/scripts/auto/js_shell/scripts/shell_help_norecord.js <==
//@ Shell Help
shell.help()

//@ Shell Help, \? [USE:Shell Help]
\? shell

//@ Help on Options
shell.help("options")

//@ Help on Options, \? [USE:Help on Options]
\? shell.options

//@ Help on Reports
shell.help("reports")

//@ Help on Reports, \? [USE:Help on Reports]
\? reports

//@ Help on addExtensionObjectMember
shell.help("addExtensionObjectMember")

//@ Help on addExtensionObjectMember, \? [USE:Help on addExtensionObjectMember]
\? addExtensionObjectMember

//@ Help on shell.addExtensionObjectMember, \? [USE:Help on addExtensionObjectMember]
\? shell.addExtensionObjectMember

//@ Help on Connect
shell.help("connect")

//@ Help on Connect, \? [USE:Help on Connect]
\? connect

//@ Help on createExtensionObject
shell.help("createExtensionObject")

//@ Help on createExtensionObject, \? [USE:Help on createExtensionObject]
\? createExtensionObject

//@ Help on shell.createExtensionObject, \? [USE:Help on createExtensionObject]
\? shell.createExtensionObject

//@ Help on deleteAllCredentials
shell.help("deleteAllCredentials")

//@ Help on deleteAllCredentials, \? [USE:Help on deleteAllCredentials]
\? deleteAllCredentials

//@ Help on deleteCredential
shell.help("deleteCredential")

//@ Help on deleteCredential, \? [USE:Help on deleteCredential]
\? deleteCredential

//@ Help on disablePager
shell.help("disablePager")

//@ Help on disablePager, \? [USE:Help on disablePager]
\? disablePager

//@ Help on enablePager
shell.help("enablePager")

//@ Help on enablePager, \? [USE:Help on enablePager]
\? enablePager

//@ Help on getSession
shell.help("getSession")

//@ Help on getSession, \? [USE:Help on getSession]
\? shell.getSession

//@ Help on Help
shell.help("help")

//@ Help on Help, \? [USE:Help on Help]
\? shell.help

//@ Help on listCredentialHelpers
shell.help("listCredentialHelpers")

//@ Help on listCredentialHelpers, \? [USE:Help on listCredentialHelpers]
\? listCredentialHelpers

//@ Help on listCredentials
shell.help("listCredentials")

//@ Help on listCredentials, \? [USE:Help on listCredentials]
\? listCredentials

//@ Help on Log
shell.help("log")

//@ Help on Log, \? [USE:Help on Log]
\? log

//@ Help on parseUri
shell.help("parseUri")

//@ Help on parseUri, \? [USE:Help on parseUri]
\? parseuri

//@ Help on Prompt
shell.help("prompt")

//@ Help on Prompt, \? [USE:Help on Prompt]
\? prompt

//@ Help on reconnect
shell.help("reconnect")

//@ Help on reconnect, \? [USE:Help on reconnect]
\? reconnect

//@ Help on registerGlobal
shell.help("registerGlobal")

//@ Help on registerGlobal, \? [USE:Help on registerGlobal]
\? registerGlobal

//@ Help on shell.registerGlobal, \? [USE:Help on registerGlobal]
\? shell.registerGlobal


//@ Help on registerReport
shell.help("registerReport")

//@ Help on registerReport, \? [USE:Help on registerReport]
\? registerReport

//@ Help on setCurrentSchema
shell.help("setCurrentSchema")

//@ Help on setCurrentSchema, \? [USE:Help on setCurrentSchema]
\? shell.setCurrentSchema

//@ Help on setSession
shell.help("setSession")

//@ Help on setSession, \? [USE:Help on setSession]
\? setSession

//@ Help on status
shell.help("status")

//@ Help on status, \? [USE:Help on status]
\? shell.status

//@ Help on storeCredential
shell.help("storeCredential")

//@ Help on storeCredential, \? [USE:Help on storeCredential]
\? storeCredential

//@ BUG28393119 UNABLE TO GET HELP ON CONNECTION DATA, before session
\? connection

//@ BUG28393119 UNABLE TO GET HELP ON CONNECTION DATA, after session
shell.connect(__mysqluripwd)
\? connection
session.close()

//@ Help on connection attributes
\? connection attributes

//@ Help on plugins
\? plugins

//@ Help on extension objects
\? extension objects

//@ Help on unparseUri
\? unparseUri

//@ Help on dumpRows
\? dumpRows

==> mysql-shell-8.0.27-src.tar.gz: mysql-shell-8.0.27-src/unittest/scripts/auto/js_shell/scripts/shell_help_norecord.js <==
//@ Shell Help
shell.help()

//@ Shell Help, \? [USE:Shell Help]
\? shell

//@ Help on Options
shell.help("options")

//@ Help on Options, \? [USE:Help on Options]
\? shell.options

//@ Help on Reports
shell.help("reports")

//@ Help on Reports, \? [USE:Help on Reports]
\? reports

//@ Help on addExtensionObjectMember
shell.help("addExtensionObjectMember")

//@ Help on addExtensionObjectMember, \? [USE:Help on addExtensionObjectMember]
\? addExtensionObjectMember

//@ Help on shell.addExtensionObjectMember, \? [USE:Help on addExtensionObjectMember]
\? shell.addExtensionObjectMember

//@ Help on Connect
shell.help("connect")

//@ Help on Connect, \? [USE:Help on Connect]
\? connect

// WL13236-TSFR4_1: Validate that the function named shell.connectToPrimary([connectionData, password]) exists under the shell global object and receives two optional parameters: connectionData and password.
// WL13236-TSFR4_2: Validate that the help system has an entry for the function shell.connectToPrimary([connectionData, password]). Test with: \h shell.connectToPrimary, \h connectToPrimary, \h shell.help('connectToPrimary'), \h shell.

//@ Help on connectToPrimary
shell.help("connectToPrimary")

//@ Help on connectToPrimary, \? [USE: Help on connectToPrimary]
\? connectToPrimary

//@ Help on shell.connectToPrimary [USE: Help on connectToPrimary]
\? shell.connectToPrimary

//@ Help on createExtensionObject
shell.help("createExtensionObject")

//@ Help on createExtensionObject, \? [USE:Help on createExtensionObject]
\? createExtensionObject

//@ Help on shell.createExtensionObject, \? [USE:Help on createExtensionObject]
\? shell.createExtensionObject

//@ Help on deleteAllCredentials
shell.help("deleteAllCredentials")

//@ Help on deleteAllCredentials, \? [USE:Help on deleteAllCredentials]
\? deleteAllCredentials

//@ Help on deleteCredential
shell.help("deleteCredential")

//@ Help on deleteCredential, \? [USE:Help on deleteCredential]
\? deleteCredential

//@ Help on disablePager
shell.help("disablePager")

//@ Help on disablePager, \? [USE:Help on disablePager]
\? disablePager

//@ Help on enablePager
shell.help("enablePager")

//@ Help on enablePager, \? [USE:Help on enablePager]
\? enablePager

//@ Help on getSession
shell.help("getSession")

//@ Help on getSession, \? [USE:Help on getSession]
\? shell.getSession

//@ Help on Help
shell.help("help")

//@ Help on Help, \? [USE:Help on Help]
\? shell.help

//@ Help on listCredentialHelpers
shell.help("listCredentialHelpers")

//@ Help on listCredentialHelpers, \? [USE:Help on listCredentialHelpers]
\? listCredentialHelpers

//@ Help on listCredentials
shell.help("listCredentials")

//@ Help on listCredentials, \? [USE:Help on listCredentials]
\? listCredentials

//@ Help on Log
shell.help("log")

//@ Help on Log, \? [USE:Help on Log]
\? log

//@ Help on parseUri
shell.help("parseUri")

//@ Help on parseUri, \? [USE:Help on parseUri]
\? parseuri

//@ Help on Prompt
shell.help("prompt")

//@ Help on Prompt, \? [USE:Help on Prompt]
\? prompt

//@ Help on shell.disconnect
shell.help("disconnect")

//@ Help on disconnect [USE: Help on shell.disconnect]
\? shell.disconnect

//@ Help on reconnect
shell.help("reconnect")

//@ Help on reconnect, \? [USE:Help on reconnect]
\? reconnect

//@ Help on registerGlobal
shell.help("registerGlobal")

//@ Help on registerGlobal, \? [USE:Help on registerGlobal]
\? registerGlobal

//@ Help on shell.registerGlobal, \? [USE:Help on registerGlobal]
\? shell.registerGlobal


//@ Help on registerReport
shell.help("registerReport")

//@ Help on registerReport, \? [USE:Help on registerReport]
\? registerReport

//@ Help on setCurrentSchema
shell.help("setCurrentSchema")

//@ Help on setCurrentSchema, \? [USE:Help on setCurrentSchema]
\? shell.setCurrentSchema

//@ Help on setSession
shell.help("setSession")

//@ Help on setSession, \? [USE:Help on setSession]
\? setSession

//@ Help on status
shell.help("status")

//@ Help on status, \? [USE:Help on status]
\? shell.status

//@ Help on storeCredential
shell.help("storeCredential")

//@ Help on storeCredential, \? [USE:Help on storeCredential]
\? storeCredential

//@ BUG28393119 UNABLE TO GET HELP ON CONNECTION DATA, before session
\? connection

//@ BUG28393119 UNABLE TO GET HELP ON CONNECTION DATA, after session
shell.connect(__mysqluripwd)
\? connection
session.close()

//@ Help on connection attributes
\? connection attributes

//@ Help on extension objects
\? extension objects

//@ Help on unparseUri
\? unparseUri

//@ Help on dumpRows
\? dumpRows
